Description Usage Arguments Details Value Examples
Add hex.R to package data-raw directory. Create a default logo.
1 | use_hex(account, host = "github")
|
account |
user account. |
host |
|
This script provides a template for package hex sticker icons, a large icon in data-raw and a small icon in inst.
A default logo is generated and placed at man/figures/logo.png. However, it will require user customization after it is generated.
Adapt the provided script and rerun to make a new logo.
The default logo.png will not be created if the magick package is not installed.
Instead, a message is printed notifying of this requirement. Being able to generate a default logo (that will surely be replaced later) is a minor, optional feature.
Therefore, pkgpeanuts does not have package dependencies in this regard.
side effect of creating file.
1 | ## Not run: use_hex(account = "username", host = "github")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.